#!/usr/bin/env python
# -*- coding: utf-8 -*-

__name__ = 'wide_wild_west'
__version__ = '0.0.1.dev2'
__author__ = 'Xavier ROY'
__author_email__ = 'xavier.roy@telecomnnancy.net'

__import__('pkg_resources').declare_namespace(__name__)


#!/usr/bin/env python
# -*- coding: utf-8 -*-


class Person:

    def __init__(self, first_name, last_name, birth_date, death_date, guns=[]):
        self.first_name = first_name
        self.last_name = last_name
        self.birth_date = birth_date
        self.death_date = death_date
        self.guns = guns


class Posse:

    def __init__(self, members):
        self.members = members


class Gun:

    def __init__(self, name: str, designer: str, manufacturer: str, model: str, year: int):
        self.name = name
        self.designer = designer
        self.manufacturer = manufacturer
        self.model = model
        self.year = year


class Handgun(Gun):

    _SINGLE_ACTION_REVOLVER = 'Single Action Revolver'
    _DOUBLE_ACTION_REVOLVER = 'Double Action Revolver'

    def __init__(self, name: str, designer: str, manufacturer: str, model: str, year: int, type):
        super().__init__(name, designer, manufacturer, model, year)
        self.type = type




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import logging.config
from monkey.ioc.core import Registry

logging.config.fileConfig('logging.conf')


def run():
    registry = Registry()
    registry.load('data/ok_coral.json')
    tombstone_police = registry.get('tombstone_police')
    for member in tombstone_police.members:
        print(member.__dict__)


if __name__ == '__main__':  # pragma: no coverage
    run()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
from setuptools import setup, find_packages

import wide_wild_west

project_dir = os.path.dirname(os.path.realpath(__file__))
requirement_file_path = project_dir + '/requirements.txt'
requirements = []
if os.path.isfile(requirement_file_path):
    with open(requirement_file_path) as f:
        requirements = f.read().splitlines()

setup(
    name=wide_wild_west.__name__,
    version=wide_wild_west.__version__,
    author=wide_wild_west.__author__,
    author_email=wide_wild_west.__author_email__,
    url='https://bitbucket.org/tncy/my-project2/',
    description='A sample project.',
    long_description=open('README.rst').read(),
    license="Apache License, Version 2.0",

    packages=find_packages(exclude=['tests', 'data']),
    include_package_data=True,
    install_requires=requirements,

    classifiers=[
        'Programming Language :: Python',
        'Development Status :: 1 - Planning',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.6',
        'Intended Audience :: Education'
    ]
)
